@@ -1,5 +1,6 @@
 from abc import abstractmethod
 import datetime
+import glob
 import logging
 import numpy as np
 import os
@@ -23,6 +24,7 @@ from pynetcf.time_series import (
 
 from .base import ReaderBase
 from .utils import numpy_timeoffsetunit, infer_cellsize
+from .exceptions import ReaderError
 
 
 class _TimeModificationMixin:
@@ -143,6 +145,24 @@ class _TimeseriesRepurposeMixin:
 
 
 class _EasierGriddedNcMixin:
+
+    def variable_description(self) -> Mapping[str, Mapping]:
+        """
+        Returns
+        -------
+        attrs : dict
+            A dictionary mapping existing variables to metadata stored in the
+            netCDF files.
+        """
+        ncfiles = glob.glob(str(Path(self.path) / "*.nc"))
+        fname = next(filter(lambda s: not s.endswith("grid.nc"), ncfiles))
+
+        with xr.open_dataset(fname) as ds:
+            uninteresting = ["row_size", "location_id", "location_description"]
+            attrs = {v: dict(ds[v].attrs) for v in list(ds.data_vars) if v not
+                     in uninteresting}
+        return attrs
+
     def _get_grid(self, ts_path, grid, kd_tree_name="pykdtree"):
         if grid is None:  # pragma: no branch
             grid = os.path.join(ts_path, "grid.nc")
@@ -606,12 +626,21 @@ class ZippedCsvTs(_GriddedNcContiguousRaggedTs, _TimeseriesRepurposeMixin):
         gpis = np.empty(len(self.fnames), dtype=int)
         self.gpi_index_map = {}
         for i, name in enumerate(self.fnames):
-            gpi = int(re.findall(r".*gpi=([0-9]+).*\.csv", name)[0])
+            match = re.findall(r".*gpi=([0-9]+).*\.csv", name)
+            if len(match) != 1:
+                raise ReaderError(f"Extracting gpi from filename {name} failed.")
+            gpi = int(match[0])
             gpis[i] = gpi
             # mapping from gpi to index for  _read_gp
             self.gpi_index_map[gpi] = i
-            lats[i] = float(re.findall(r".*lat=([0-9.]+).*\.csv", name)[0])
-            lons[i] = float(re.findall(r".*lon=([0-9.]+).*\.csv", name)[0])
+            match = re.findall(r".*lat=([0-9.]+).*\.csv", name)
+            if len(match) != 1:
+                raise ReaderError(f"Extracting lat from filename {name} failed.")
+            lats[i] = float(match[0])
+            match = re.findall(r".*lon=([0-9.]+).*\.csv", name)
+            if len(match) != 1:
+                raise ReaderError(f"Extracting lon from filename {name} failed.")
+            lons[i] = float(match[0])
 
         # create grid object
         grid = BasicGrid(lons, lats, gpis=gpis)
